@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 
 from sqlbuilder import smartsql as sb
 from pyar import exc, url, util
@@ -28,7 +28,6 @@ SMARTSQL_DIALECTS = {
     'postgis': 'postgres',
     'oracle': 'oracle',
 }
-#sb.default_dialect(SMARTSQL_DIALECTS.get(_dns_url.drivername, DEFAULT_DIALECT))
 
 class ModelBase(object):
     _auto_commit_  = True
@@ -214,6 +213,15 @@ class Model(ModelBase):
     def __del__(self):
         self.end()
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        del self
+        if traceback is not None:
+            return False
+        return True
+
 
 if __name__ == '__main__':
     import time, sys
